
import adsk.core, adsk.fusion, traceback

def run(context):
    ui = None
    try:
        title = 'ATH - Sketch Import'
        app = adsk.core.Application.get()
        ui = app.userInterface
        design = app.activeProduct
        if not design:
            ui.messageBox('No active Fusion design', title)
            return

        dlg = ui.createFileDialog()
        dlg.title = 'Import ATH Sketch'
        dlg.filter = 'ATH Sketch File (*.asc);;All Files (*.*)'
        if dlg.showOpen() != adsk.core.DialogResults.DialogOK:
            return

        f = open(dlg.filename, 'r')
        root = design.rootComponent

        z0 = 0.0
        #points = adsk.core.ObjectCollection.create()
        line = f.readline()
        while line:
            if line[0] == '#':
                line = f.readline()
                continue
            items = line.split(';')
            n = len(items) - 1
            if n < 1:
                line = f.readline()
                continue

            cmd = int(items[0])
            if cmd == 10:
                sketch = root.sketches.add(root.xYConstructionPlane)
                #points = sketch.sketchPoints
                points = adsk.core.ObjectCollection.create()
                if n == 2:
                    z0 = float(items[1])
            elif cmd == 12:
                sketch.sketchCurves.sketchCircles.addByCenterRadius(
                    adsk.core.Point3D.create(0.0, 0.0, z0), float(items[1])
                )
            elif cmd == 40:
                if n == 4:
                    z = float(items[3])
                else:
                    z = z0
                points.add(adsk.core.Point3D.create(float(items[1]), float(items[2]), z))
            elif cmd == 50:
                points.add(points.item(0))
                sketch.sketchCurves.sketchFittedSplines.add(points)
            elif cmd == 52:
                ps = adsk.core.ObjectCollection.create()
                for i in range(1,n):
                    ps.add(points[int(items[i])])
                sketch.sketchCurves.sketchFittedSplines.add(ps)
            elif cmd == 54:
                if n == 3:
                    sketch.sketchCurves.sketchLines.addTwoPointRectangle(
                        points[int(items[1])], points[int(items[2])]
                    )

            line = f.readline()
        f.close()
        
    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
