
import adsk.core, adsk.fusion, traceback

def run(context):
    ui = None
    try:
        title = 'ATH - Sketch Import'
        app = adsk.core.Application.get()
        ui = app.userInterface
        design = app.activeProduct
        if not design:
            ui.messageBox('No active Fusion design', title)
            return

        dlg = ui.createFileDialog()
        dlg.title = 'Import ATH Sketch'
        dlg.filter = 'ATH Sketch File (*.asc);;All Files (*.*)'
        if dlg.showOpen() != adsk.core.DialogResults.DialogOK:
            return

        f = open(dlg.filename, 'r')
        root = design.rootComponent

        z0 = 0.0 #default Z location
        
        profiles = [] #init array to store loft profiles

        line = f.readline()
        while line:
            if line[0] == '#':
                line = f.readline()
                continue
            items = line.split(';')
            n = len(items) - 1
            if n < 1:
                line = f.readline()
                continue

            cmd = int(items[0])
            if cmd == 10:
                sketch = root.sketches.add(root.xYConstructionPlane)
                #points = sketch.sketchPoints
                points = adsk.core.ObjectCollection.create()
                if n == 2:
                    z0 = float(items[1])
            elif cmd == 11: #draw a plane using three points
                # Create sketch
                sketch = root.sketches.add(root.xZConstructionPlane)
                sketchPoints = sketch.sketchPoints

                # Create three sketch points from user input
                coordsOne = str.split(items[1],',')
                positionOne = adsk.core.Point3D.create(float(coordsOne[0]), float(coordsOne[1]), float(coordsOne[2]))
                sketchPointOne = sketchPoints.add(positionOne)
                coordsTwo = str.split(items[2],',')
                positionTwo = adsk.core.Point3D.create(float(coordsTwo[0]), float(coordsTwo[1]), float(coordsTwo[2]))
                sketchPointTwo = sketchPoints.add(positionTwo)
                coordsThree = str.split(items[3],',')
                positionThree = adsk.core.Point3D.create(float(coordsThree[0]), float(coordsThree[1]), float(coordsThree[2]))
                sketchPointThree = sketchPoints.add(positionThree)

                # Add construction plane by three points
                ctorPlanes = root.constructionPlanes # Get construction planes
                ctorPlaneInput1 = ctorPlanes.createInput() # Create construction plane input
                ctorPlaneInput1.setByThreePoints(sketchPointOne, sketchPointTwo, sketchPointThree) #SketchPointOne is the center of the plane
                ctorPlane1 = ctorPlanes.add(ctorPlaneInput1)
                sketch =  root.sketches.add(ctorPlane1)
                points = adsk.core.ObjectCollection.create()
                

            elif cmd == 12:
                sketch.sketchCurves.sketchCircles.addByCenterRadius(
                    adsk.core.Point3D.create(0.0, 0.0, z0), float(items[1])
                )
                #profile = sketch.profiles.item(0) #need to work out how to append to array instead
                profiles.append(sketch.profiles.item(0))
            elif cmd == 40:
                if n == 4:
                    z = float(items[3])
                else:
                    z = z0
                points.add(adsk.core.Point3D.create(float(items[1]), float(items[2]), z))
            elif cmd == 50:
                points.add(points.item(0))
                sketch.sketchCurves.sketchFittedSplines.add(points)
                profiles.append(sketch.profiles.item(0))
            elif cmd == 52:
                ps = adsk.core.ObjectCollection.create()
                for i in range(1,n):
                    ps.add(points[int(items[i])])
                sketch.sketchCurves.sketchFittedSplines.add(ps)
            elif cmd == 54: 
                if n == 3:
                    sketch.sketchCurves.sketchLines.addTwoPointRectangle(
                        points[int(items[1])], points[int(items[2])]
                    )
                    profiles.append(sketch.profiles.item(0))
            elif cmd == 60: #loft profiles command        
                loftFeats = root.features.loftFeatures
                loftInput = loftFeats.createInput(adsk.fusion.FeatureOperations.NewBodyFeatureOperation)
                loftSectionsObj = loftInput.loftSections
                for i in range(0, len(profiles)):
                    loftSectionsObj.add(profiles[i])
                loftInput.isSolid = False
                loftInput.isClosed = False
                loftInput.isTangentEdgesMerged = True

                # Create loft feature
                loftFeats.add(loftInput)


            line = f.readline()
        f.close()
        
    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
